@@ -52,6 +52,20 @@ pub(crate) fn tidy_balances(date: NaiveDate, db_conn: &mut impl ConnCache) -> Re
         to_insert.insert(db_conn)?;
     }
 
+    // From bad delete txs, final balance got corrupted but monthly balances are fine.
+    // If does not match, trust the monthly balances
+    let mut final_balance = Balance::get_final_balance(db_conn)?;
+    let balance_highest_date = Balance::get_balance_highest_date(db_conn)?;
+
+    for balance in balance_highest_date {
+        let mut final_balance_entry = final_balance.get_mut(&balance.method_id).unwrap().clone();
+
+        if final_balance_entry.balance != balance.balance {
+            final_balance_entry.balance = balance.balance;
+            final_balance_entry.insert(db_conn)?;
+        }
+    }
+
     Ok(())
 }
 
