@@ -44,11 +44,11 @@ pub(crate) fn get_txs(
 
     for tx in txs {
         match &tx.tx_type {
-            TxType::Income => {
+            TxType::Income | TxType::Borrow | TxType::LendRepay => {
                 let method_id = tx.from_method.id;
                 *last_balance.get_mut(&method_id).unwrap() += tx.amount;
             }
-            TxType::Expense => {
+            TxType::Expense | TxType::Lend | TxType::BorrowRepay => {
                 let method_id = tx.from_method.id;
                 *last_balance.get_mut(&method_id).unwrap() -= tx.amount;
             }
@@ -113,7 +113,7 @@ impl TxViewGroup {
 
         let mut to_return = vec![vec![String::new()]];
 
-        to_return[0].extend(sorted_methods.iter().map(|m| m.name.to_string()));
+        to_return[0].extend(sorted_methods.iter().map(|m| m.name.clone()));
 
         to_return[0].push(String::from("Total"));
 
@@ -171,7 +171,7 @@ impl TxViewGroup {
             }
 
             let changes_value = changes.get(&method_id).unwrap();
-            to_insert_changes.push(changes_value.to_string());
+            to_insert_changes.push(changes_value.clone());
 
             let method_income = *income.get(&method_id).unwrap();
             total_income += method_income;
@@ -357,7 +357,7 @@ impl TxViewGroup {
 
         let mut to_return = vec![vec![String::new()]];
 
-        to_return[0].extend(sorted_methods.iter().map(|m| m.name.to_string()));
+        to_return[0].extend(sorted_methods.iter().map(|m| m.name.clone()));
 
         to_return[0].push(String::from("Total"));
 
@@ -392,8 +392,8 @@ impl TxViewGroup {
                     let amount = target_tx.tx.amount;
 
                     match target_tx.tx.tx_type {
-                        TxType::Income => balance -= amount,
-                        TxType::Expense => balance += amount,
+                        TxType::Income | TxType::Borrow | TxType::LendRepay => balance -= amount,
+                        TxType::Expense | TxType::Lend | TxType::BorrowRepay => balance += amount,
                         TxType::Transfer => {
                             if method_id == target_tx.tx.from_method.id {
                                 balance += amount;
@@ -443,13 +443,13 @@ impl TxViewGroup {
                 };
 
                 match tx_type {
-                    TxType::Income => {
+                    TxType::Income | TxType::Borrow | TxType::LendRepay => {
                         if from_method == method_id {
                             method_balance += amount;
                             total_balance += amount;
                         }
                     }
-                    TxType::Expense => {
+                    TxType::Expense | TxType::Lend | TxType::BorrowRepay => {
                         if from_method == method_id {
                             method_balance -= amount;
                             total_balance -= amount;
@@ -472,7 +472,7 @@ impl TxViewGroup {
             to_insert_balance.push(format!("{:.2}", method_balance.dollar()));
 
             let changes_value = changes.get(&method_id).unwrap();
-            to_insert_changes.push(changes_value.to_string());
+            to_insert_changes.push(changes_value.clone());
         }
 
         to_insert_balance.push(format!("{:.2}", total_balance.dollar()));
